---
layout: "fastly"
page_title: "Fastly: fastly_dictionaries"
sidebar_current: "docs-fastly-datasource-fastly_dictionaries"
description: |-
  Get information on Fastly service dictionaries.
---

# fastly_dictionaries

Use this data source to get a list of [Fastly dictionaries][1] for the specified service/version.

## Example Usage

```terraform
resource "fastly_service_vcl" "example" {
  name = "Example Service"

  domain {
    name = "example.com"
  }

  dictionary {
    name = "example_1"
  }

  dictionary {
    name = "example_2"
  }

  dictionary {
    name = "example_3"
  }

  force_destroy = true
}

data "fastly_dictionaries" "example" {
  depends_on      = [fastly_service_vcl.example]
  service_id      = fastly_service_vcl.example.id
  service_version = fastly_service_vcl.example.active_version
}

output "service_dictionaries" {
  value = data.fastly_dictionaries.example
}
```

[1]: https://developer.fastly.com/reference/api/dictionaries/

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `service_id` (String) Alphanumeric string identifying the service.
- `service_version` (Number) Integer identifying a service version.

### Read-Only

- `dictionaries` (Set of Object) List of all dictionaries for the version of the service. (see [below for nested schema](#nestedatt--dictionaries))
- `id` (String) The ID of this resource.

<a id="nestedatt--dictionaries"></a>
### Nested Schema for `dictionaries`

Read-Only:

- `id` (String)
- `name` (String)
- `write_only` (Boolean)
