---
layout: "fastly"
page_title: "Fastly: integration"
sidebar_current: "docs-fastly-resource-integration"
description: |-
  Provides a Fastly integration. Fastly will use these integrations to send you notifications and alerts related to the Fastly product. Mailing list, Microsoft Teams, New Relic, PagerDuty, Slack, and webhook are supported as integrations.
---

# fastly_integration

Provides a Fastly integration. Fastly will use these integrations to send you notifications and alerts related to the Fastly product. Mailing list, Microsoft Teams, New Relic, PagerDuty, Slack, and webhook are supported as integrations.

~> **IMPORTANT:** The mailing list integrations require confirmation. To send a confirmation email and verify integration status, after applying changes using Terraform, please visit https://manage.fastly.com/observability/alerts/integrations

## Example Usage

```terraform
resource "fastly_integration" "mailinglist_example" {
  name = "my mailing list integration"
  description = "example mailing list integration"
  type = "mailinglist"

  config = {
    # mailing list address
    address = "incoming-hook@my.domain.com"
  }
}

resource "fastly_integration" "microsoftteams_example" {
  name = "my Microsoft Teams integration"
  description = "example Microsoft Teams integration"
  type = "microsoftteams"

  config = {
    # Microsoft Teams webhook URL
    webhook = "https://m365x012345.webhook.office.com"
  }
}

resource "fastly_integration" "newrelic_example" {
  name = "my New Relic integration"
  description = "example New Relic integration"
  type = "newrelic"

  config = {
    # New Relic account ID and license key
    account = "XXXXXXX"
    key = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
  }
}

resource "fastly_integration" "pagerduty_example" {
  name = "my PagerDuty integration"
  description = "example PagerDuty integration"
  type = "pagerduty"

  config = {
    # PagerDuty integration key
    key = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX"
  }
}

resource "fastly_integration" "slack_example" {
  name = "my Slack integration"
  description = "example Slack integration"
  type = "slack"

  config = {
    # Slack webhook URL
    webhook = "https://hooks.slack.com/services/T00000000/B00000000/XXXXXXXXXXXXXXXXXXXXXXXX"
  }
}

resource "fastly_integration" "webhook_example" {
  name = "my webhook integration"
  description = "example webhook integration"
  type = "webhook"

  config = {
    # webhook URL
    webhook = "https://my.domain.com/webhook"
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `config` (Map of String, Sensitive) Configuration specific to the integration `type` (see documentation examples).
- `name` (String) User submitted name of the integration.
- `type` (String) Type of the integration. One of: `mailinglist`, `microsoftteams`, `newrelic`, `pagerduty`, `slack`, `webhook`.

### Optional

- `description` (String) User submitted description of the integration.

### Read-Only

- `id` (String) The ID of this resource.
